# -*- coding: utf-8 -*-
from setuphelpers import *
from setupdevhelpers import *
import waptlicences


def table_to_list(table):
  result = []
  for row in table.find_all('tr')[2:]:
    for col in row.find_all('td'):
        link = col.find('a')
        if link:
            result.append(link.string)
  return result

def update_package():
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name

    base_url = f"https://packages.vmware.com/tools/releases/latest/windows/{control.architecture}/"
    latest_release_name = table_to_list(bs_find(base_url, 'table'))[-1]
    
    download_url = f"{base_url}{latest_release_name}"
    latest_bin = latest_release_name
    version = '.'.join(latest_bin.split('-')[2:4])

    print(f"Latest {app_name} version is: {version}")
    print(f"Download URL is: {download_url}")

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print("Binary is present: %s" % latest_bin)

    # Deleting binaries
    for f in glob.glob("*.exe"):
        if f != latest_bin:
            remove_file(f)

    expected_issuer = ['VMware, Inc.', 'Broadcom Inc']
    sign_name = waptlicences.check_exe_signing_certificate(latest_bin)[0]
    if sign_name not in expected_issuer:
        error(f'Bad issuer {sign_name} != {expected_issuer}')

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print(f"Software version updated (from: {control.get_software_version()} to: {version})")
        package_updated = True
    else:
        print(f"Software version up-to-date ({version})")

    control.set_software_version(get_version_from_binary(latest_bin))
    control.save_control_to_wapt()

    return package_updated